-------------------------------------------------------------------------------
--                L  O  C  A  L     V  A  R  I  A  B  L  E  S
-------------------------------------------------------------------------------

local addonName, L = ...;

-------------------------------------------------------------------------------
--                L  O  C  A  L     F  U  N  C  T  I  O  N  S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
--                G  L  O  B  A  L    F  U  N  C  T  I  O  N  S
-------------------------------------------------------------------------------

--
-- Function to enable/disable Merchant Search
--
function NigglesMerchantSearchEnable()
  -- Create the Merchant Search edit box, if required
  if ((NigglesMerchantSearch == nil) and
      (NigglesDBC.settings.UiMerchantSearch)) then
    CreateFrame("EDITBOX", "NigglesMerchantSearch", MerchantFrame, 
      "NigglesMerchantSearchTemplate");
  end

  -- Check if Merchant Search is enabled
  if (NigglesDBC.settings.UiMerchantSearch) then
    -- Show the Merchant Search edit box
    NigglesMerchantSearch:Show();

    -- Update the Merchant's frame, if shown
    if (MerchantFrame:IsShown()) then
      MerchantFrame_Update();
    end
  else
    -- Hide the Merchant Search edit box, if required
    if (NigglesMerchantSearch ~= nil) then
      NigglesMerchantSearch:Hide();
    end
  end

  return;
end

--
-- Function used to update the Merchant frame, based on the search text
--
function NigglesMerchantSearchUpdate()
  -- Local Variables
  local itemName;
  local itemButton;
  local merchantButton;
  local searchText;

  -- Check if searching is enabled
  if ((NigglesDBC.settings.UiMerchantSearch) and
      (MerchantFrame.selectedTab == 1)) then
    -- Get the search text
    searchText = NigglesMerchantSearch:GetText();
    if ((searchText == SEARCH) or (searchText == nil)) then
      searchText = "";
    else
      searchText = string.lower(searchText);
    end

    -- Set the vertex colour, depending on the buttons' text
    for buttonIdx = 1, MERCHANT_ITEMS_PER_PAGE do
      merchantButton = _G["MerchantItem"..buttonIdx];
      itemButton     = _G["MerchantItem"..buttonIdx.."ItemButton"];
      itemName       = _G["MerchantItem"..buttonIdx.."Name"];
      if ((itemButton:IsShown()) and
          (searchText ~= "") and
          (string.find(string.lower(itemName:GetText() or ""), searchText,
            1, true) == nil)) then
        SetItemButtonNameFrameVertexColor(merchantButton, 0.3, 0.3, 0.3);
        SetItemButtonSlotVertexColor(merchantButton, 0.3, 0.3, 0.3);
        SetItemButtonTextureVertexColor(itemButton, 0.3, 0.3, 0.3);
        SetItemButtonNormalTextureVertexColor(itemButton, 0.3, 0.3, 0.3);
        itemName:SetAlpha(0.3);
      else
        itemName:SetAlpha(1.0);
      end
    end

    -- Show/Hide the Clear button
    if (searchText ~= "") then
      NigglesMerchantSearch.clearButton:Show();
    else
      NigglesMerchantSearch.clearButton:Hide();
    end
  end

  return;
end
